==> ejc-jlincome-api-3.0.0-20240419.235511-14-sources.jar: com/ejianc/business/jlincome/performance/vo/SaleContractVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 绩效管理-销售业绩合同
 * 
 * @author generator
 * 
 */
public class SaleContractVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long contractId; // 合同ID
    private String contractCode; // 合同code
    private String contractName; // 合同名称
    private Long projectId; // 合同所属项目ID
    private String projectCode; // 合同所属项目code
    private String projectName; // 合同所属项目名称
    private Long orgId; // 区域ID
    private String orgCode; // 区域code
    private String orgName; // 区域名称
    private Long saleId; // 销售负责人ID
    private String saleCode; // 销售负责人code
    private String saleName; // 销售负责人
    private Long customerId; // 客户ID
    private String customerName; // 客户名称
    private BigDecimal contractMny; // 合同金额
    private BigDecimal contractTaxMny; // 合同金额
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    private Date registerDate; // 销售合同登记日期
    private BigDecimal registerMny; // 登记金额
    private BigDecimal totalRegisterMny; // 累计登记金额
    private BigDecimal includeTotalRegisterMny; // 含本次累计登记金额
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private String memo; // 备注
    private Integer billState; // 单据状态（审批必须字段）
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    //TODO 合同参照编码
    @ReferSerialTransfer(referCode="           ")
    public Long getContractId() {
        return contractId;
    }

    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    //TODO 项目参照编码
    @ReferSerialTransfer(referCode="           ")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    //TODO 销售负责人参照编码
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSaleId() {
        return saleId;
    }

    @ReferDeserialTransfer
    public void setSaleId(Long saleId) {
        this.saleId = saleId;
    }
    public String getSaleCode() {
        return saleCode;
    }

    public void setSaleCode(String saleCode) {
        this.saleCode = saleCode;
    }
    public String getSaleName() {
        return saleName;
    }

    public void setSaleName(String saleName) {
        this.saleName = saleName;
    }
    //TODO 客户参照编码
    @ReferSerialTransfer(referCode="           ")
    public Long getCustomerId() {
        return customerId;
    }

    @ReferDeserialTransfer
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public Date getRegisterDate() {
        return registerDate;
    }

    public void setRegisterDate(Date registerDate) {
        this.registerDate = registerDate;
    }
    public BigDecimal getRegisterMny() {
        return registerMny;
    }

    public void setRegisterMny(BigDecimal registerMny) {
        this.registerMny = registerMny;
    }
    public BigDecimal getTotalRegisterMny() {
        return totalRegisterMny;
    }

    public void setTotalRegisterMny(BigDecimal totalRegisterMny) {
        this.totalRegisterMny = totalRegisterMny;
    }
    public BigDecimal getIncludeTotalRegisterMny() {
        return includeTotalRegisterMny;
    }

    public void setIncludeTotalRegisterMny(BigDecimal includeTotalRegisterMny) {
        this.includeTotalRegisterMny = includeTotalRegisterMny;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-jlincome-api-3.0.0-20240507.065206-52-sources.jar: com/ejianc/business/jlincome/performance/vo/SaleContractVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 绩效管理-销售业绩合同
 * 
 * @author generator
 * 
 */
public class SaleContractVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long contractId; // 合同ID
    private String contractCode; // 合同code
    private String contractName; // 合同名称
    private Long projectId; // 合同所属项目ID
    private String projectCode; // 合同所属项目code
    private String projectName; // 合同所属项目名称
    private Long orgId; // 区域ID
    private String orgCode; // 区域code
    private String orgName; // 区域名称
    private Long saleId; // 销售负责人ID
    private String saleCode; // 销售负责人code
    private String saleName; // 销售负责人
    private Long customerId; // 客户ID
    private String customerName; // 客户名称
    private BigDecimal contractMny; // 合同金额
    private BigDecimal contractTaxMny; // 合同金额
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    private Date registerDate; // 销售合同登记日期
    private BigDecimal registerMny; // 登记金额
    private BigDecimal totalRegisterMny; // 累计登记金额
    private BigDecimal includeTotalRegisterMny; // 含本次累计登记金额
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private String memo; // 备注
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(exist = false)
    private String billStateName; // 单据状态字段翻译

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    //TODO 合同参照编码
//    @ReferSerialTransfer(referCode="           ")
    public Long getContractId() {
        return contractId;
    }

//    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    //TODO 项目参照编码
//    @ReferSerialTransfer(referCode="           ")
    public Long getProjectId() {
        return projectId;
    }

//    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    //TODO 销售负责人参照编码
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSaleId() {
        return saleId;
    }

    @ReferDeserialTransfer
    public void setSaleId(Long saleId) {
        this.saleId = saleId;
    }
    public String getSaleCode() {
        return saleCode;
    }

    public void setSaleCode(String saleCode) {
        this.saleCode = saleCode;
    }
    public String getSaleName() {
        return saleName;
    }

    public void setSaleName(String saleName) {
        this.saleName = saleName;
    }
    //TODO 客户参照编码
//    @ReferSerialTransfer(referCode="           ")
    public Long getCustomerId() {
        return customerId;
    }

//    @ReferDeserialTransfer
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public Date getRegisterDate() {
        return registerDate;
    }

    public void setRegisterDate(Date registerDate) {
        this.registerDate = registerDate;
    }
    public BigDecimal getRegisterMny() {
        return registerMny;
    }

    public void setRegisterMny(BigDecimal registerMny) {
        this.registerMny = registerMny;
    }
    public BigDecimal getTotalRegisterMny() {
        return totalRegisterMny;
    }

    public void setTotalRegisterMny(BigDecimal totalRegisterMny) {
        this.totalRegisterMny = totalRegisterMny;
    }
    public BigDecimal getIncludeTotalRegisterMny() {
        return includeTotalRegisterMny;
    }

    public void setIncludeTotalRegisterMny(BigDecimal includeTotalRegisterMny) {
        this.includeTotalRegisterMny = includeTotalRegisterMny;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}
